==> dqops-0.2.0.5-py2.py3-none-any.whl: dqops/client/api/checks/get_check.py <==
from http import HTTPStatus
from typing import Any, Dict, Optional

import httpx

from ... import errors
from ...client import Client
from ...models.check_spec_model import CheckSpecModel
from ...types import Response


def _get_kwargs(
    full_check_name: str,
    *,
    client: Client,
) -> Dict[str, Any]:
    url = "{}api/checks/{fullCheckName}".format(
        client.base_url, fullCheckName=full_check_name
    )

    headers: Dict[str, str] = client.get_headers()
    cookies: Dict[str, Any] = client.get_cookies()

    return {
        "method": "get",
        "url": url,
        "headers": headers,
        "cookies": cookies,
        "timeout": client.get_timeout(),
        "follow_redirects": client.follow_redirects,
    }


def _parse_response(
    *, client: Client, response: httpx.Response
) -> Optional[CheckSpecModel]:
    if response.status_code == HTTPStatus.OK:
        response_200 = CheckSpecModel.from_dict(response.json())

        return response_200
    if client.raise_on_unexpected_status:
        raise errors.UnexpectedStatus(response.status_code, response.content)
    else:
        return None


def _build_response(
    *, client: Client, response: httpx.Response
) -> Response[CheckSpecModel]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def sync_detailed(
    full_check_name: str,
    *,
    client: Client,
) -> Response[CheckSpecModel]:
    """getCheck

     Returns a check definition

    Args:
        full_check_name (str):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[CheckSpecModel]
    """

    kwargs = _get_kwargs(
        full_check_name=full_check_name,
        client=client,
    )

    response = httpx.request(
        verify=client.verify_ssl,
        **kwargs,
    )

    return _build_response(client=client, response=response)


def sync(
    full_check_name: str,
    *,
    client: Client,
) -> Optional[CheckSpecModel]:
    """getCheck

     Returns a check definition

    Args:
        full_check_name (str):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        CheckSpecModel
    """

    return sync_detailed(
        full_check_name=full_check_name,
        client=client,
    ).parsed


async def asyncio_detailed(
    full_check_name: str,
    *,
    client: Client,
) -> Response[CheckSpecModel]:
    """getCheck

     Returns a check definition

    Args:
        full_check_name (str):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[CheckSpecModel]
    """

    kwargs = _get_kwargs(
        full_check_name=full_check_name,
        client=client,
    )

    async with httpx.AsyncClient(verify=client.verify_ssl) as _client:
        response = await _client.request(**kwargs)

    return _build_response(client=client, response=response)


async def asyncio(
    full_check_name: str,
    *,
    client: Client,
) -> Optional[CheckSpecModel]:
    """getCheck

     Returns a check definition

    Args:
        full_check_name (str):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        CheckSpecModel
    """

    return (
        await asyncio_detailed(
            full_check_name=full_check_name,
            client=client,
        )
    ).parsed

==> dqops-1.0.1-py2.py3-none-any.whl: dqops/client/api/checks/get_check.py <==
from http import HTTPStatus
from typing import Any, Dict, Optional, Union

import httpx

from ... import errors
from ...client import AuthenticatedClient, Client
from ...models.check_definition_model import CheckDefinitionModel
from ...types import Response


def _get_kwargs(
    full_check_name: str,
) -> Dict[str, Any]:
    pass

    return {
        "method": "get",
        "url": "api/checks/{fullCheckName}".format(
            fullCheckName=full_check_name,
        ),
    }


def _parse_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Optional[CheckDefinitionModel]:
    if response.status_code == HTTPStatus.OK:
        response_200 = CheckDefinitionModel.from_dict(response.json())

        return response_200
    if client.raise_on_unexpected_status:
        raise errors.UnexpectedStatus(response.status_code, response.content)
    else:
        return None


def _build_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Response[CheckDefinitionModel]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def sync_detailed(
    full_check_name: str,
    *,
    client: AuthenticatedClient,
) -> Response[CheckDefinitionModel]:
    """getCheck

     Returns a check definition

    Args:
        full_check_name (str):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[CheckDefinitionModel]
    """

    kwargs = _get_kwargs(
        full_check_name=full_check_name,
    )

    response = client.get_httpx_client().request(
        **kwargs,
    )

    return _build_response(client=client, response=response)


def sync(
    full_check_name: str,
    *,
    client: AuthenticatedClient,
) -> Optional[CheckDefinitionModel]:
    """getCheck

     Returns a check definition

    Args:
        full_check_name (str):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        CheckDefinitionModel
    """

    return sync_detailed(
        full_check_name=full_check_name,
        client=client,
    ).parsed


async def asyncio_detailed(
    full_check_name: str,
    *,
    client: AuthenticatedClient,
) -> Response[CheckDefinitionModel]:
    """getCheck

     Returns a check definition

    Args:
        full_check_name (str):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[CheckDefinitionModel]
    """

    kwargs = _get_kwargs(
        full_check_name=full_check_name,
    )

    response = await client.get_async_httpx_client().request(**kwargs)

    return _build_response(client=client, response=response)


async def asyncio(
    full_check_name: str,
    *,
    client: AuthenticatedClient,
) -> Optional[CheckDefinitionModel]:
    """getCheck

     Returns a check definition

    Args:
        full_check_name (str):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        CheckDefinitionModel
    """

    return (
        await asyncio_detailed(
            full_check_name=full_check_name,
            client=client,
        )
    ).parsed
